#[repr(i32)]
pub enum OutputAudioEncoding { Unspecified, Linear16, Mp3, Mp364Kbps, OggOpus, Mulaw, }
Audio encoding of the output audio format in Text-To-Speech.

Variants



Unspecified

Not specified.



Linear16

Uncompressed 16-bit signed little-endian samples (Linear PCM). Audio content returned as LINEAR16 also contains a WAV header.



Mp3

MP3 audio at 32kbps.



Mp364Kbps

MP3 audio at 64kbps.



OggOpus

Opus encoded audio wrapped in an ogg container. The result will be a file which can be played natively on Android, and in browsers (at least Chrome and Firefox). The quality of the encoding is considerably higher than MP3 while using approximately the same bitrate.



Mulaw

8-bit samples that compand 14-bit audio samples using G.711 PCMU/mu-law.

Implementations

source

impl OutputAudioEncoding

source

pub fn is_valid(value: i32) -> bool

Returns true if value is a variant of OutputAudioEncoding.

source

pub fn from_i32(value: i32) -> Option<OutputAudioEncoding>

Converts an i32 to a OutputAudioEncoding, or None if value is not a valid variant.

source

impl OutputAudioEncoding

source

pub fn as_str_name(&self) -> &'static str

String value of the enum field names used in the ProtoBuf definition.

The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.